GroupSidebarItems class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- GroupSidebarItems
Constructors
-
GroupSidebarItems({Key? key, required List<
AdaptiveGroupDestination> groupDestinations, required List<SidebarItem> items, required int currentIndex, required ValueChanged<int> onChanged, SidebarItemSize itemSize = SidebarItemSize.medium, ScrollController? scrollController}) -
const
Properties
- currentIndex → int
-
The current selected index. It must be in the range of 0 to
items.lengthfinalinherited - cursor → MouseCursor?
-
Specifies the kind of cursor to use for all sidebar items.
finalinherited
-
groupDestinations
→ List<
AdaptiveGroupDestination> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
items
→ List<
SidebarItem> -
The
SidebarItems used by the sidebar. If no items are provided, the sidebar is not rendered.finalinherited - itemSize → SidebarItemSize
-
The size specifications for all
items.finalinherited - key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
onChanged
→ ValueChanged<
int> -
Called when the current selected index should be changed.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollController → ScrollController?
-
The scroll controller used by this sidebar. If null, a local scroll
controller is created.
finalinherited
- selectedColor → Color?
-
The color to paint the item when it's selected.
finalinherited
- shape → ShapeBorder?
-
The
shapeproperty specifies the outline (border) of the decoration. The shape must not be null. It's used alongsideselectedColor.finalinherited - unselectedColor → Color?
-
The color to paint the item when it's unselected.
finalinherited
Methods
-
build(
BuildContext context) → Widget - Describes the part of the user interface represented by this widget.
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited