kPagePadding top-level constant
double
const kPagePadding
The recommended padding around page content in Yaru applications.
Implementation
const kPagePadding = 20.0;
The recommended padding around page content in Yaru applications.
const kPagePadding = 20.0;